pub enum SegmentAnythingInferenceError {
RunModel(Error),
MergeMasks,
}Expand description
An error that can occur when running a SegmentAnything model.
Variants
RunModel(Error)
An error that can occur when trying to run a SegmentAnything model.
MergeMasks
An error that can occur when converting the result of a SegmentAnything model to an image.